==> yndenz-modules-yndenz-seo-1.5.1-5a895b.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.5.1] - 2019-03-13
### Fixed
- Breadcrumb active item microformats

## [1.5.0] - 2019-03-12
### Changed
- Package name comply with composer v2 restrictions

## [1.4.0] - 2019-03-12
### Added
- Address details in JSON+LD

### Changed
- Only add microformats to breadcrumb when using Yoast SEO < 7.7

## [1.3.1] - 2019-03-12
### Fixed
- Breadcrumb microformats

## [1.3.0] - 2018-10-05
### Added
- Support to direct display title and description

### Changed
- Code style set to WordPress standards

## [1.2.1] - 2018-09-17
### Changed
- Compatible with multiple version of base-module

## [1.2.0] - 2018-08-30
### Added
- Context in string translation

## [1.1.7] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.5.1...HEAD
[1.5.1]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.5.0...1.5.1
[1.5.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.4.0...1.5.0
[1.4.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.3.1...1.4.0
[1.3.1]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.3.0...1.3.1
[1.3.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.2.1...1.3.0
[1.2.1]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.2.0...1.2.1
[1.2.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.1.7...1.2.0
[1.1.7]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.1.6...1.1.7

==> yndenz-modules-yndenz-seo-1.6.0-b65a07.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.6.0] - 2019-10-10
### Changed
- Remove all microformats when Yoast SEO plugin provides JSON+LD

## [1.5.2] - 2019-10-10
### Fixed
- get_permalink() for last breadcrumb item doesn't work on archive pages

## [1.5.1] - 2019-03-13
### Fixed
- Breadcrumb active item microformats

## [1.5.0] - 2019-03-12
### Changed
- Package name comply with composer v2 restrictions

## [1.4.0] - 2019-03-12
### Added
- Address details in JSON+LD

### Changed
- Only add microformats to breadcrumb when using Yoast SEO < 7.7

## [1.3.1] - 2019-03-12
### Fixed
- Breadcrumb microformats

## [1.3.0] - 2018-10-05
### Added
- Support to direct display title and description

### Changed
- Code style set to WordPress standards

## [1.2.1] - 2018-09-17
### Changed
- Compatible with multiple version of base-module

## [1.2.0] - 2018-08-30
### Added
- Context in string translation

## [1.1.7] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.6.0...HEAD
[1.6.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.5.2...1.6.0
[1.5.2]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.5.1...1.5.2
[1.5.1]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.5.0...1.5.1
[1.5.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.4.0...1.5.0
[1.4.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.3.1...1.4.0
[1.3.1]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.3.0...1.3.1
[1.3.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.2.1...1.3.0
[1.2.1]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.2.0...1.2.1
[1.2.0]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.1.7...1.2.0
[1.1.7]: https://gitlab.yndenz.com/yndenz-modules/yndenzSEO/compare/1.1.6...1.1.7
